;(function(){
  var map = {
  "commitId": "22b936a1d390f2be51c40130ef9b2787f7faed1a",
  "branchName": "release-client-5.14.x",
  "buildTime": "Sun, 28 May 2023 13:22:50 GMT",
  "buildVersion": "261",
  "css": [
    "@zoom/client-scheduler/static/css/chunk-vendors.af34567c.css",
    "@zoom/client-scheduler/static/css/index.39b774a5.css"
  ],
  "js": [
    "@zoom/client-scheduler/static/js/chunk-vendors.c685a8ed.js",
    "@zoom/client-scheduler/static/js/index.23c56d52.js"
  ]
};
  var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
  map.css && map.css.forEach(function (cssItem) {
    var linkTag = document.createElement('link');
    var cssURL = prefix +  cssItem ;
    linkTag.href = cssURL;
    linkTag.setAttribute('rel','stylesheet');
    document.head.appendChild(linkTag);
  });
  map.js && map.js.forEach(function (jsItem) {
    var scriptTag = document.createElement("script");
    var jsURL = prefix +  jsItem;
    scriptTag.setAttribute("src", jsURL);
    document.body.appendChild(scriptTag);
  });
  window.domainFromServer= "https://dev-integration.zoomdev.us/fe-static/";
})();
